import React, { useState } from 'react';
import { BrowserRouter, Route, Switch, withRouter } from 'react-router-dom';

import { makeStyles } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';

import SwipeableDrawer from '@material-ui/core/SwipeableDrawer';
import List from '@material-ui/core/List';
import Divider from '@material-ui/core/Divider';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import ListIcon from '@material-ui/icons/List';
import SettingsIcon from '@material-ui/icons/Settings';


import injectSettings from 'lib/settings';


/* *** layout *** */

const useStyles = makeStyles(theme => ({
    root: {
        flexGrow: 1,
    },
    menuButton: {
        marginRight: theme.spacing(2),
    },
    title: {
        flexGrow: 1,
    },

    list: {
        width: 250,
    },
    fullList: {
        width: 'auto',
    },    
}));

// layout copied from material-ui
const Layout = (props) => {
    const classes = useStyles();
    const [open, toggleDrawer] = useState(false);

    return (
        <div className={ classes.root }>
            <AppBar position="static">
                <Toolbar>
                    <IconButton edge="start" className={ classes.menuButton } color="inherit" aria-label="menu" onClick={ () => toggleDrawer(!open) }>
                        <MenuIcon />
                    </IconButton>
                    <Typography variant="h6" className={ classes.title }>
                        Settings
                    </Typography>
                </Toolbar>
            </AppBar>


            { props.children }

            <SwipeableDrawer
                open={ open }
                onClose={ () => toggleDrawer(false) }
                onOpen={ () => toggleDrawer(true) }
                >
                
                <List>
                    <ListItem button>
                        <ListItemIcon><ListIcon /></ListItemIcon>
                        <ListItemText primary="Projects" />
                    </ListItem>
                </List>
                <Divider/>
                <List>
                    <ListItem button>
                        <ListItemIcon><SettingsIcon /></ListItemIcon>
                        <ListItemText primary="Settings" />
                    </ListItem>
                </List>

            </SwipeableDrawer>

        </div>
    );
}



/* *** routes - main app *** */
const App = injectSettings(({ settings, ...props }) => {
    return (
        <BrowserRouter>

            <Route path="/" render={ (props) => (
                <Layout {...props}>
                    <Switch>
                        <Route path="*" render={ (props) => <p>Not implemented</p> } />
                    </Switch>
                </Layout>
            ) }/>        
        </BrowserRouter>
    );

});

export default App;
